# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/toolbar.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(94, 543)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMaximumSize(QtCore.QSize(16777215, 16777215))
        Form.setStyleSheet("")
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.side_toolbar_container = QtWidgets.QFrame(parent=Form)
        self.side_toolbar_container.setFrameShape(QtWidgets.QFrame.Shape.NoFrame)
        self.side_toolbar_container.setFrameShadow(QtWidgets.QFrame.Shadow.Raised)
        self.side_toolbar_container.setObjectName("side_toolbar_container")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.side_toolbar_container)
        self.gridLayout_2.setContentsMargins(3, 3, 3, 3)
        self.gridLayout_2.setHorizontalSpacing(3)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.active_grid_area_button = QtWidgets.QPushButton(parent=self.side_toolbar_container)
        self.active_grid_area_button.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.active_grid_area_button.sizePolicy().hasHeightForWidth())
        self.active_grid_area_button.setSizePolicy(sizePolicy)
        self.active_grid_area_button.setMinimumSize(QtCore.QSize(0, 0))
        self.active_grid_area_button.setMaximumSize(QtCore.QSize(40, 40))
        self.active_grid_area_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.active_grid_area_button.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/038-drag.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.active_grid_area_button.setIcon(icon)
        self.active_grid_area_button.setIconSize(QtCore.QSize(24, 24))
        self.active_grid_area_button.setCheckable(True)
        self.active_grid_area_button.setChecked(False)
        self.active_grid_area_button.setAutoExclusive(False)
        self.active_grid_area_button.setFlat(True)
        self.active_grid_area_button.setObjectName("active_grid_area_button")
        self.gridLayout_2.addWidget(self.active_grid_area_button, 1, 0, 1, 1)
        self.nsfw_button = QtWidgets.QPushButton(parent=self.side_toolbar_container)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nsfw_button.sizePolicy().hasHeightForWidth())
        self.nsfw_button.setSizePolicy(sizePolicy)
        self.nsfw_button.setMinimumSize(QtCore.QSize(0, 0))
        self.nsfw_button.setMaximumSize(QtCore.QSize(40, 40))
        self.nsfw_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.nsfw_button.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/039-18.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.nsfw_button.setIcon(icon1)
        self.nsfw_button.setIconSize(QtCore.QSize(24, 24))
        self.nsfw_button.setCheckable(True)
        self.nsfw_button.setChecked(False)
        self.nsfw_button.setFlat(True)
        self.nsfw_button.setObjectName("nsfw_button")
        self.gridLayout_2.addWidget(self.nsfw_button, 9, 0, 1, 1)
        self.grid_button = QtWidgets.QPushButton(parent=self.side_toolbar_container)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.grid_button.sizePolicy().hasHeightForWidth())
        self.grid_button.setSizePolicy(sizePolicy)
        self.grid_button.setMinimumSize(QtCore.QSize(0, 0))
        self.grid_button.setMaximumSize(QtCore.QSize(40, 40))
        self.grid_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.grid_button.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/032-pixels.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.grid_button.setIcon(icon2)
        self.grid_button.setIconSize(QtCore.QSize(24, 24))
        self.grid_button.setCheckable(True)
        self.grid_button.setFlat(True)
        self.grid_button.setObjectName("grid_button")
        self.gridLayout_2.addWidget(self.grid_button, 6, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 10, 0, 1, 1)
        self.focus_button = QtWidgets.QPushButton(parent=self.side_toolbar_container)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.focus_button.sizePolicy().hasHeightForWidth())
        self.focus_button.setSizePolicy(sizePolicy)
        self.focus_button.setMinimumSize(QtCore.QSize(0, 0))
        self.focus_button.setMaximumSize(QtCore.QSize(40, 40))
        self.focus_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.focus_button.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/037-focus.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.focus_button.setIcon(icon3)
        self.focus_button.setIconSize(QtCore.QSize(24, 24))
        self.focus_button.setFlat(True)
        self.focus_button.setObjectName("focus_button")
        self.gridLayout_2.addWidget(self.focus_button, 5, 0, 1, 1)
        self.eraser_button = QtWidgets.QPushButton(parent=self.side_toolbar_container)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eraser_button.sizePolicy().hasHeightForWidth())
        self.eraser_button.setSizePolicy(sizePolicy)
        self.eraser_button.setMinimumSize(QtCore.QSize(0, 0))
        self.eraser_button.setMaximumSize(QtCore.QSize(40, 40))
        self.eraser_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.eraser_button.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/014-eraser.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.eraser_button.setIcon(icon4)
        self.eraser_button.setIconSize(QtCore.QSize(24, 24))
        self.eraser_button.setCheckable(True)
        self.eraser_button.setChecked(False)
        self.eraser_button.setFlat(True)
        self.eraser_button.setObjectName("eraser_button")
        self.gridLayout_2.addWidget(self.eraser_button, 3, 0, 1, 1)
        self.brush_button = QtWidgets.QPushButton(parent=self.side_toolbar_container)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.brush_button.sizePolicy().hasHeightForWidth())
        self.brush_button.setSizePolicy(sizePolicy)
        self.brush_button.setMinimumSize(QtCore.QSize(0, 0))
        self.brush_button.setMaximumSize(QtCore.QSize(40, 40))
        self.brush_button.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/011-pencil.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.brush_button.setIcon(icon5)
        self.brush_button.setIconSize(QtCore.QSize(24, 24))
        self.brush_button.setCheckable(True)
        self.brush_button.setFlat(True)
        self.brush_button.setObjectName("brush_button")
        self.gridLayout_2.addWidget(self.brush_button, 2, 0, 1, 1)
        self.move_button = QtWidgets.QPushButton(parent=self.side_toolbar_container)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.move_button.sizePolicy().hasHeightForWidth())
        self.move_button.setSizePolicy(sizePolicy)
        self.move_button.setMaximumSize(QtCore.QSize(40, 40))
        self.move_button.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/013-move-selector.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.move_button.setIcon(icon6)
        self.move_button.setIconSize(QtCore.QSize(24, 24))
        self.move_button.setCheckable(True)
        self.move_button.setFlat(True)
        self.move_button.setObjectName("move_button")
        self.gridLayout_2.addWidget(self.move_button, 4, 0, 1, 1)
        self.gridLayout.addWidget(self.side_toolbar_container, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.active_grid_area_button.setToolTip(_translate("Form", "Active Grid Area"))
        self.active_grid_area_button.setShortcut(_translate("Form", "M"))
        self.nsfw_button.setToolTip(_translate("Form", "Toggle NSFW Filter"))
        self.grid_button.setToolTip(_translate("Form", "Toggle Grid"))
        self.grid_button.setShortcut(_translate("Form", "G"))
        self.focus_button.setToolTip(_translate("Form", "Recenter Canvas"))
        self.eraser_button.setToolTip(_translate("Form", "Eraser"))
        self.eraser_button.setShortcut(_translate("Form", "E"))
        self.brush_button.setToolTip(_translate("Form", "Pen"))
        self.brush_button.setStyleSheet(_translate("Form", "border-color: rgb(61, 56, 70);"))
        self.brush_button.setShortcut(_translate("Form", "B"))
        self.move_button.setStyleSheet(_translate("Form", "border-color: rgb(61, 56, 70);"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/noise_filter.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(258, 215)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(30, 180, 221, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayoutWidget = QtWidgets.QWidget(parent=Dialog)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 10, 241, 167))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.verticalLayoutWidget)
        self.gridLayout_9.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.gridLayout_8 = QtWidgets.QGridLayout()
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.red_slider = QtWidgets.QSlider(parent=self.verticalLayoutWidget)
        self.red_slider.setMinimum(0)
        self.red_slider.setMaximum(1000)
        self.red_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.red_slider.setObjectName("red_slider")
        self.gridLayout_8.addWidget(self.red_slider, 1, 0, 1, 1)
        self.red_spinbox = QtWidgets.QDoubleSpinBox(parent=self.verticalLayoutWidget)
        self.red_spinbox.setMinimum(0.0)
        self.red_spinbox.setMaximum(1.0)
        self.red_spinbox.setSingleStep(0.01)
        self.red_spinbox.setObjectName("red_spinbox")
        self.gridLayout_8.addWidget(self.red_spinbox, 1, 1, 1, 1)
        self.label_8 = QtWidgets.QLabel(parent=self.verticalLayoutWidget)
        self.label_8.setObjectName("label_8")
        self.gridLayout_8.addWidget(self.label_8, 0, 0, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_8, 0, 0, 1, 1)
        self.gridLayout_7 = QtWidgets.QGridLayout()
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.green_slider = QtWidgets.QSlider(parent=self.verticalLayoutWidget)
        self.green_slider.setMinimum(0)
        self.green_slider.setMaximum(1000)
        self.green_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.green_slider.setObjectName("green_slider")
        self.gridLayout_7.addWidget(self.green_slider, 1, 0, 1, 1)
        self.green_spinbox = QtWidgets.QDoubleSpinBox(parent=self.verticalLayoutWidget)
        self.green_spinbox.setMinimum(0.0)
        self.green_spinbox.setMaximum(1.0)
        self.green_spinbox.setSingleStep(0.01)
        self.green_spinbox.setObjectName("green_spinbox")
        self.gridLayout_7.addWidget(self.green_spinbox, 1, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(parent=self.verticalLayoutWidget)
        self.label_7.setObjectName("label_7")
        self.gridLayout_7.addWidget(self.label_7, 0, 0, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_7, 1, 0, 1, 1)
        self.gridLayout_6 = QtWidgets.QGridLayout()
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.blue_slider = QtWidgets.QSlider(parent=self.verticalLayoutWidget)
        self.blue_slider.setMinimum(0)
        self.blue_slider.setMaximum(1000)
        self.blue_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.blue_slider.setObjectName("blue_slider")
        self.gridLayout_6.addWidget(self.blue_slider, 1, 0, 1, 1)
        self.blue_spinbox = QtWidgets.QDoubleSpinBox(parent=self.verticalLayoutWidget)
        self.blue_spinbox.setMinimum(0.0)
        self.blue_spinbox.setMaximum(1.0)
        self.blue_spinbox.setSingleStep(0.01)
        self.blue_spinbox.setObjectName("blue_spinbox")
        self.gridLayout_6.addWidget(self.blue_spinbox, 1, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(parent=self.verticalLayoutWidget)
        self.label_6.setObjectName("label_6")
        self.gridLayout_6.addWidget(self.label_6, 0, 0, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_6, 2, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Color Balance"))
        self.label_8.setText(_translate("Dialog", "Red"))
        self.label_7.setText(_translate("Dialog", "Green"))
        self.label_6.setText(_translate("Dialog", "Blue"))



from PyQt6.QtWidgets import QColorDialog
import webbrowser
from airunner.windows.about import AboutWindow
from airunner.windows.model_merger import ModelMerger
from airunner.windows.settings import SettingsWindow


class ToolbarMixin:
    def initialize(self):
        self.toolbar_widget.initialize()
        # self.select_button.clicked.connect(lambda: self.set_tool("select"))
        self.actionAbout.triggered.connect(self.show_about)
        self.actionModel_Merger.triggered.connect(self.show_model_merger)
        self.actionBug_report.triggered.connect(lambda: webbrowser.open(
            "https://github.com/Capsize-Games/airunner/issues/new?assignees=&labels=&template=bug_report.md&title="))
        self.actionReport_vulnerability.triggered.connect(
            lambda: webbrowser.open("https://github.com/Capsize-Games/airunner/security/advisories/new"))
        self.actionDiscord.triggered.connect(lambda: webbrowser.open("https://discord.gg/PUVDDCJ7gz"))
        self.actionInvert.triggered.connect(self.do_invert)
        self.actionFilm.triggered.connect(self.do_film)
        self.actionSettings.triggered.connect(self.show_settings)
        # self.initialize_toolbar_extensions()  # TODO: Extensions

    """
    TODO: Extensions
    def initialize_toolbar_extensions(self):
        self.actionExtensions.triggered.connect(self.show_extensions)
    
    def show_extensions(self):
        self.extensions_window = ExtensionsWindow(self.settings_manager)
    """

    def show_settings(self):
        SettingsWindow(self.settings_manager, app=self)

    def do_invert(self):
        self.history.add_event({
            "event": "apply_filter",
            "layer_index": self.canvas.current_layer_index,
            "images": self.canvas.image_data_copy(self.canvas.current_layer_index),
        })
        self.canvas.invert_image()
        self.canvas.update()

    def do_film(self):
        self.canvas.film_filter()

    def show_canvas_color(self):
        # show a color widget dialog and set the canvas color
        color = QColorDialog.getColor()
        if color.isValid():
            color = color.name()
            self.settings_manager.settings.canvas_color.set(color)
            self.canvas.set_canvas_color()

    def show_model_merger(self):
        ModelMerger(self.settings_manager, app=self)

    def show_about(self):
        AboutWindow(self.settings_manager, app=self)

    def set_tool(self, tool):
        self.toolbar_widget.set_tool(tool)
        if self.settings_manager.settings.current_tool.get() != tool:
            self.settings_manager.settings.current_tool.set(tool)
        else:
            self.settings_manager.settings.current_tool.set(None)
        self.canvas.update_cursor()

    def toggle_grid(self, event):
        self.settings_manager.settings.show_grid.set(
            event
        )
        self.canvas.update()

    def focus_button_clicked(self):
        self.canvas.recenter()

    def toggle_darkmode(self):
        self.set_stylesheet()



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/header.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_header(object):
    def setupUi(self, header):
        header.setObjectName("header")
        header.resize(970, 50)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(header.sizePolicy().hasHeightForWidth())
        header.setSizePolicy(sizePolicy)
        header.setMinimumSize(QtCore.QSize(0, 0))
        header.setMaximumSize(QtCore.QSize(16777215, 68))
        self.gridLayout = QtWidgets.QGridLayout(header)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.frame = QtWidgets.QFrame(parent=header)
        self.frame.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Shadow.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.undo_button = QtWidgets.QPushButton(parent=self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.undo_button.sizePolicy().hasHeightForWidth())
        self.undo_button.setSizePolicy(sizePolicy)
        self.undo_button.setMinimumSize(QtCore.QSize(0, 0))
        self.undo_button.setMaximumSize(QtCore.QSize(40, 40))
        self.undo_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.undo_button.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/007-undo.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.undo_button.setIcon(icon)
        self.undo_button.setIconSize(QtCore.QSize(24, 24))
        self.undo_button.setFlat(True)
        self.undo_button.setObjectName("undo_button")
        self.gridLayout_2.addWidget(self.undo_button, 0, 4, 1, 1)
        self.redo_button = QtWidgets.QPushButton(parent=self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.redo_button.sizePolicy().hasHeightForWidth())
        self.redo_button.setSizePolicy(sizePolicy)
        self.redo_button.setMinimumSize(QtCore.QSize(0, 0))
        self.redo_button.setMaximumSize(QtCore.QSize(40, 40))
        self.redo_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.redo_button.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/008-redo.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.redo_button.setIcon(icon1)
        self.redo_button.setIconSize(QtCore.QSize(24, 24))
        self.redo_button.setFlat(True)
        self.redo_button.setObjectName("redo_button")
        self.gridLayout_2.addWidget(self.redo_button, 0, 5, 1, 1)
        self.save_button = QtWidgets.QPushButton(parent=self.frame)
        self.save_button.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/033-diskette.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.save_button.setIcon(icon2)
        self.save_button.setIconSize(QtCore.QSize(24, 24))
        self.save_button.setFlat(True)
        self.save_button.setObjectName("save_button")
        self.gridLayout_2.addWidget(self.save_button, 0, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 0, 6, 1, 1)
        self.file_new_button = QtWidgets.QPushButton(parent=self.frame)
        self.file_new_button.setMaximumSize(QtCore.QSize(40, 40))
        self.file_new_button.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/036-new-document.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.file_new_button.setIcon(icon3)
        self.file_new_button.setIconSize(QtCore.QSize(24, 24))
        self.file_new_button.setFlat(True)
        self.file_new_button.setObjectName("file_new_button")
        self.gridLayout_2.addWidget(self.file_new_button, 0, 0, 1, 1)
        self.open_button = QtWidgets.QPushButton(parent=self.frame)
        self.open_button.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/034-folder.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.open_button.setIcon(icon4)
        self.open_button.setIconSize(QtCore.QSize(24, 24))
        self.open_button.setFlat(True)
        self.open_button.setObjectName("open_button")
        self.gridLayout_2.addWidget(self.open_button, 0, 1, 1, 1)
        self.gridLayout.addWidget(self.frame, 0, 0, 1, 1)

        self.retranslateUi(header)
        QtCore.QMetaObject.connectSlotsByName(header)

    def retranslateUi(self, header):
        _translate = QtCore.QCoreApplication.translate
        header.setWindowTitle(_translate("header", "Form"))
        self.undo_button.setToolTip(_translate("header", "Undo"))
        self.redo_button.setToolTip(_translate("header", "Redo"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/lora_container.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(583, 775)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.toggleAllLora = QtWidgets.QCheckBox(parent=Form)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.toggleAllLora.setFont(font)
        self.toggleAllLora.setChecked(False)
        self.toggleAllLora.setTristate(False)
        self.toggleAllLora.setObjectName("toggleAllLora")
        self.gridLayout.addWidget(self.toggleAllLora, 0, 0, 1, 1)
        self.lora_scroll_area = QtWidgets.QScrollArea(parent=Form)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.lora_scroll_area.setFont(font)
        self.lora_scroll_area.setFrameShape(QtWidgets.QFrame.Shape.NoFrame)
        self.lora_scroll_area.setFrameShadow(QtWidgets.QFrame.Shadow.Plain)
        self.lora_scroll_area.setWidgetResizable(True)
        self.lora_scroll_area.setObjectName("lora_scroll_area")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 583, 755))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.lora_scroll_area.setWidget(self.scrollAreaWidgetContents_2)
        self.gridLayout.addWidget(self.lora_scroll_area, 1, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.toggleAllLora.setText(_translate("Form", "Toggle all"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/prompt_browser_prompt_widget.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(395, 304)
        self.gridLayout_2 = QtWidgets.QGridLayout(Form)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(parent=Form)
        font = QtGui.QFont()
        font.setPointSize(11)
        font.setBold(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.prompt = QtWidgets.QTextBrowser(parent=Form)
        self.prompt.setObjectName("prompt")
        self.gridLayout.addWidget(self.prompt, 1, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(parent=Form)
        font = QtGui.QFont()
        font.setBold(True)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.negative_prompt = QtWidgets.QTextBrowser(parent=Form)
        self.negative_prompt.setObjectName("negative_prompt")
        self.gridLayout.addWidget(self.negative_prompt, 3, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.load_button = QtWidgets.QPushButton(parent=Form)
        self.load_button.setObjectName("load_button")
        self.horizontalLayout.addWidget(self.load_button)
        self.delete_button = QtWidgets.QPushButton(parent=Form)
        self.delete_button.setObjectName("delete_button")
        self.horizontalLayout.addWidget(self.delete_button)
        self.gridLayout.addLayout(self.horizontalLayout, 4, 0, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label.setText(_translate("Form", "Prompt"))
        self.label_3.setText(_translate("Form", "Negative Prompt"))
        self.load_button.setText(_translate("Form", "Load"))
        self.delete_button.setText(_translate("Form", "Delete"))



# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/tool_menu.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(410, 495)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(250, 0))
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.right_toolbar = QtWidgets.QWidget(parent=Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.right_toolbar.sizePolicy().hasHeightForWidth())
        self.right_toolbar.setSizePolicy(sizePolicy)
        self.right_toolbar.setMinimumSize(QtCore.QSize(0, 0))
        self.right_toolbar.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setItalic(False)
        self.right_toolbar.setFont(font)
        self.right_toolbar.setStyleSheet("border-top-color: rgba(191, 64, 64, 0);")
        self.right_toolbar.setObjectName("right_toolbar")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.right_toolbar)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout.addWidget(self.right_toolbar, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))



from PyQt6.QtGui import QColor, QPen, QPainter


class CanvasGridMixin:
    @property
    def active_grid_area_selected(self):
        return self.settings_manager.settings.current_tool.get() == "active_grid_area"

    @property
    def grid_size(self):
        return self.settings_manager.settings.size.get()

    def initialize(self):
        # Set the grid line color and thickness
        # convert self.settings_manager.settings.canvas_color.get() to QColor
        self.grid_pen = QPen(
            QColor(self.settings_manager.settings.line_color.get()),
            self.settings_manager.settings.line_width.get()
        )

    def update_grid_pen(self):
        self.grid_pen = QPen(
            QColor(self.settings_manager.settings.line_color.get()),
            self.settings_manager.settings.line_width.get()
        )
        self.update()

    def draw_grid(self, painter):
        if not self.settings_manager.settings.show_grid.get():
            return

        # Define the starting and ending coordinates for the grid lines
        start_x = self.pos_x % self.grid_size
        end_x = self.canvas_container.width()
        start_y = self.pos_y % self.grid_size
        end_y = self.canvas_container.height()

        line_width = self.settings_manager.settings.line_width.get()
        self.grid_pen.setWidth(line_width)
        # Draw horizontal grid lines
        y = start_y
        while y < end_y:
            painter.setPen(self.grid_pen)
            painter.drawLine(0, y, self.canvas_container.width(), y)
            y += self.grid_size

        # Draw vertical grid lines
        x = start_x
        while x < end_x:
            painter.setPen(self.grid_pen)
            painter.drawLine(x, 0, x, self.canvas_container.height())
            x += self.grid_size

    def paintEvent(self, event):
        # Draw the grid and any lines that have been drawn by the user
        # draw grid
        if not self.saving:
            painter = QPainter(self.canvas_container)
            self.draw_grid(painter)
            painter.end()
